function E = function_E(beta_transl, eps_aniso, d_rot, beta_rot_array, tau_g, I_mx, A_mx, R_mx, B_mx, u0)
%function_E 
%   Echo attenuation according to Eq.(87)


%----------------------------------------------------------------------

E = zeros(size(beta_rot_array));
for RRR = 1:length(beta_rot_array) % The cycle allows to vary spin position R in [0, L/2] when integrating 
    
%----------------------------------------------------------------------
   
    beta_rot = beta_rot_array(RRR);

%----------------------------------------------------------------------
% Adjust matrix size

    Mmax = size(I_mx, 1);
    two_pi_R_over_h = beta_rot*tau_g;
    pure_helix_coefficients = function_helix_coefficients(Mmax, two_pi_R_over_h);     
    M = find(abs(pure_helix_coefficients) > 1e-12, 1, 'last');
    M = max([5, M]);
    if M > 950
        disp('function_E.m: WARNING: the matrix is too large, M > 950.');
        disp('The calculations will be slow. The precision may be lowered.');
    end
    I_mx = I_mx(1:M, 1:M);
    A_mx = A_mx(1:M, 1:M);
    R_mx = R_mx(1:M, 1:M);
    B_mx = B_mx(1:M, 1:M);
    u0 = u0(1:M);

%----------------------------------------------------------------------
    
    a = beta_transl^2;
    A = -a*(I_mx + eps_aniso*A_mx);
    B = -d_rot*R_mx + 1i*beta_rot*B_mx; % rectangular gradient
    
%----------------------------------------------------------------------
% Sphere, rectangular gradient

    if eps_aniso == 0
       MMM = (1/3)*A*tau_g^3 + B*tau_g;
       Pgu0 = expm(MMM)*u0;            
    end
    
%----------------------------------------------------------------------    
% Rod, rectangular gradient
    
    if eps_aniso > 0
        
        N = 50;
        dt = tau_g/N;
        yyy = u0;
        for kkk = 1:N
            t1 = (kkk - 1)*dt;
            t2 = t1 + dt;
            yyy = expm(A*(t2^3 - t1^3)/3 + B*dt)*yyy;    
        end
        y50 = yyy;
        
        N = 100;
        dt = tau_g/N;
        yyy = u0;
        for kkk = 1:N
            t1 = (kkk - 1)*dt;
            t2 = t1 + dt;
            yyy = expm(A*(t2^3 - t1^3)/3 + B*dt)*yyy;    
        end
        y100 = yyy;
        
        dy = norm(y100 - y50);
        dy_over_y = dy/norm(y100);
        if (dy > 1e-6) || (dy_over_y > 1e-6)
            disp(['function_E: WARNING: slow convergence, [dy, dy_over_y] = [' num2str(dy) ', ' num2str(dy_over_y) ']'] );
        end
        
        Pgu0 = y100;
        
    end

%----------------------------------------------------------------------
% Free diffusion after rectangular gradient

    a = (beta_transl*tau_g)^2;
    Mf = -a*(I_mx + eps_aniso*A_mx) - d_rot*R_mx;
    tau_free = 1/2 - tau_g;
    E(RRR) = ( norm( expm(tau_free*Mf)*Pgu0 ) )^2;

%----------------------------------------------------------------------

end % RRR

end % of function_E

