function ECHO = function_E_array_of_L_T_G(rod_length_array, rod_width, T_full_array, small_delta, G_array, I_mx, A_mx, R_mx, B_mx, u0)
%function_E_array_of_L_T_G
%   calculates attenuation according to Eq.(87) for end-labeled rods, 
%   for an array of rod lengths, array of diffusion delays, and array of gradients


%----------------------------------------------------------------------

[gamma1H, ~, ~] = function_physical_consts();

%----------------------------------------------------------------------

[D0_array, eps_aniso_array, Drot_array] = function_rod_diffusion_coefficients(rod_length_array, rod_width);

%----------------------------------------------------------------------

ECHO = zeros(length(rod_length_array), length(T_full_array), length(G_array));
LLLMAX = length(rod_length_array);
strLLLMAX = num2str(LLLMAX);
for LLL = 1:LLLMAX
    if mod(LLL, 10) == 0
        disp([num2str(LLL) ' of ' strLLLMAX]);
    end
    L = rod_length_array(LLL);
    D0 = D0_array(LLL);
    eps_aniso = eps_aniso_array(LLL);  
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        tau_g = small_delta/T;
        d_rot = Drot_array(LLL)*T;
        for GGG = 1:length(G_array)
            G0 = G_array(GGG);
            beta_transl = gamma1H*G0*sqrt(D0*T)*T;
            R = L/2; % end-labeled rods
            beta_rot = gamma1H*G0*R*T;
            ECHO(LLL, TTT, GGG) = function_E(beta_transl, eps_aniso, d_rot, beta_rot, tau_g, I_mx, A_mx, R_mx, B_mx, u0);
        end
    end
end

%----------------------------------------------------------------------

end % of function_E_array_of_L_T_G

