function ECHO = function_E_transl_array_L_T_G(rod_length_array, rod_width, T_full_array, small_delta, G_array)
%function_E_transl_array_L_T_G
%   calculates translational attenuation for end-labeled rod according to Eqs.(103)-(105) for
%   array of rod length, array of T_full and array of gradients


%----------------------------------------------------------------------

[gamma1H, ~, ~] = function_physical_consts();

%----------------------------------------------------------------------

[D0_array, eps_aniso_array, ~] = function_rod_diffusion_coefficients(rod_length_array, rod_width);

%----------------------------------------------------------------------

ECHO = zeros(length(rod_length_array), length(T_full_array), length(G_array));
LLLMAX = length(rod_length_array);
strLLLMAX = num2str(LLLMAX);
for LLL = 1:LLLMAX
    if mod(LLL, 100) == 0
        disp([num2str(LLL) ' of ' strLLLMAX]);
    end    
    L = rod_length_array(LLL);
    D0 = D0_array(LLL);
    eps_aniso = eps_aniso_array(LLL);  
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        taug = small_delta/T;
        for GGG = 1:length(G_array)
            G0 = G_array(GGG);
            beta_transl = gamma1H*G0*sqrt(D0*T)*T;
            R = L/2; % end-labeled rod
            beta_rot = gamma1H*G0*R*T;
            ECHO(LLL, TTT, GGG) = function_E_transl(beta_transl, eps_aniso, beta_rot, taug);
        end % GGG
    end % TTT
end % LLL

%----------------------------------------------------------------------

end % of function_E_transl_array_L_T_G
