function [I_mx, A_mx, R_mx, B_mx, u0] = function_I_A_R_B_u0_matrices(M)
%function_I_A_R_B_u0_matrices
%  defines matrices I_mx, A_mx, R_mx, B_mx, according to Eqs.(83)-(86) 
%  and also the vector u0, Eq.(82)


%----------------------------------------------------------------------
% The identity matrix

I_mx = eye(M);
I_mx = sparse(I_mx);

%----------------------------------------------------------------------
% A_mx according to Eq.(84)

lll = 0:(M - 1); % lll counts matrix columns
ddd = (2/3)*lll.*(lll+1)./((2*lll-1).*(2*lll+3));

lll = 2:(M - 1);  % lll counts matrix columns
aaa = lll.*(lll-1)./(sqrt(2*lll-3).*(2*lll-1).*sqrt(2*lll+1));

A_mx = diag(ddd) + diag(aaa, +2) + diag(aaa, -2);
A_mx = sparse(A_mx);

%----------------------------------------------------------------------
% R_mx according to Eq.(85)

lll = 0:(M - 1);  % lll counts matrix columns
ddd = lll.*(lll+1);

R_mx = diag(ddd);
R_mx = sparse(R_mx);

%----------------------------------------------------------------------
% B_mx according to Eq.(86)

lll = 1:(M - 1);  % lll counts matrix columns
aaa = lll./sqrt((2*lll-1).*(2*lll+1));

B_mx = diag(aaa, +1) + diag(aaa, -1);
B_mx = sparse(B_mx);

%----------------------------------------------------------------------
% Vector u0, Eq.(82)
u0 = zeros(M, 1);
u0(1) = 1;
u0 = sparse(u0);

%----------------------------------------------------------------------

end % of function_I_A_R_B_u0_matrices

