function [] = function__Fig_3_MotionalNarrowing()
%function__Fig_3_MotionalNarrowing 
%   generates Fig.3 based on Eq.(87)

%----------------------------------------------------------------------

Mmax = 1000;
[I_mx, A_mx, R_mx, B_mx, u0] = function_I_A_R_B_u0_matrices(Mmax);

% --------------------------------------------------------------------

tau_g = 1/2; % back-to-back gradients; tau_g = small_delta/T_full = 1/2

% --------------------------------------------------------------------

beta_transl = 0; % pure rotation
eps_aniso = 0; % sphere
d_rot_array = logspace(-3, 3, 50);

beta_rot = 10;

E_rot_back2back = zeros(size(d_rot_array));
for iii = 1:length(d_rot_array)
    disp(iii);
    d_rot_iii = d_rot_array(iii);   
    E_rot_back2back(iii) = function_E(beta_transl, eps_aniso, d_rot_iii, beta_rot, tau_g, I_mx, A_mx, R_mx, B_mx, u0);    
end

% --------------------------------------------------------------------

figure;
semilogx(d_rot_array, E_rot_back2back, '-ob');
grid on;
title('Fig. 3. Motional narrowing, semilogx plot');
xlabel('d\_rot');
ylabel('E\_rot\_sphere');
drawnow;
pause(1);

% --------------------------------------------------------------------

fig_for_publication = figure;
xxx = d_rot_array;
yyy = E_rot_back2back;
semilogx(xxx, yyy, 'LineStyle', '-', 'LineWidth', 1, 'Color', 'b', ...
                    'Marker', '.', 'MarkerEdgeColor', 'b', 'MarkerFaceColor', 'b', 'MarkerSize', 12);
fig_for_publication.Units = 'centimeters';
fig_for_publication.Position = [3 3 8.5 8.5*(3/4)];
ax = gca;
ax.LineWidth = 1.5;

ax.XTick = logspace(-3, 3, 7);
ax.XAxis.MinorTickValues = [2e-3, 4e-3, 6e-3, 8e-3, ...
                            2e-2, 4e-2, 6e-2, 8e-2, ...
                            2e-1, 4e-1, 6e-1, 8e-1, ...
                            2e0, 4e0, 6e0, 8e0, ...
                            2e1, 4e1, 6e1, 8e1, ...
                            2e2, 4e2, 6e2, 8e2];

ax.YTick = 0:0.2:1.0;
yticklabels({'0', '0.2', '0.4', '0.6', '0.8', '1.0'});
                      
axis([1e-3 1e3 0.0 1.0]);
grid on;
grid minor;
grid minor;

xlabel('$d_{rot}$','Interpreter','latex','FontSize', 16);
ylabel('$E_{rot,sphere}$','Interpreter','latex','FontSize', 16);

drawnow;
pause(1);

% exportgraphics(fig_for_publication,'Fig3.pdf','ContentType','vector');
% exportgraphics(fig_for_publication,'Fig3.eps','ContentType','vector');
% exportgraphics(fig_for_publication,'Fig3.tiff','Resolution',2000);

% --------------------------------------------------------------------


end % of function__Fig_3_MotionalNarrowing

