function [] = function__Fig_4_RodEnd()
%function__Fig_4_RodEnd
%   calculates and plots echo attenuation according to Eq.(87) 
%   for an array of rod lengths, array of diffusion delays, and array of gradients

%----------------------------------------------------------------------

Mmax = 1000;
[I_mx, A_mx, R_mx, B_mx, u0] = function_I_A_R_B_u0_matrices(Mmax);

%----------------------------------------------------------------------

rod_length_array = [0.23, 1.4, 6.3, 39]*1e-4; % in cm, 0.23 1.4 6.3 39 microns
rod_width = 10*1e-7; % in cm, = 10 nm

%----------------------------------------------------------------------

Gmax = 32;
xxx = linspace(0, Gmax^2, 11);
G_array = sqrt(xxx);
G_array(1) = 1;

%----------------------------------------------------------------------

small_delta = 5.4e-3; % 5.4 ms, gradient duration
BIG_DELTA_array = [small_delta,  30e-3, 50e-3, 70e-3, 100e-3, 150e-3, 200e-3, 300e-3, 500e-3, 700e-3, 1000e-3,];  
T_full_array = BIG_DELTA_array + small_delta;

%----------------------------------------------------------------------

[gamma1H, kBT, etaH2O] = function_physical_consts();

%----------------------------------------------------------------------
% Rod diffusion coefficients

[D0_array, eps_aniso_array, Drot_array] = function_rod_diffusion_coefficients(rod_length_array, rod_width);

%----------------------------------------------------------------------
% Calculate attenuation

ECHO = zeros(length(rod_length_array), length(T_full_array), length(G_array));
for LLL = 1:length(rod_length_array)
    
    L = rod_length_array(LLL);
    R = L/2; % spin-label at the end of rod
    D0 = D0_array(LLL);
    eps_aniso = eps_aniso_array(LLL);    
    Drot = Drot_array(LLL);
    
    for TTT = 1:length(T_full_array)        
        disp([LLL, TTT]);
        T = T_full_array(TTT);
        tau_g = small_delta/T;    
        d_rot = Drot*T;
        
        for GGG = 1:length(G_array)
            G = G_array(GGG);
            beta_transl = gamma1H*G*sqrt(D0*T)*T;
            beta_rot = gamma1H*G*R*T;
            ECHO(LLL, TTT, GGG) = function_E(beta_transl, eps_aniso, d_rot, beta_rot, tau_g, I_mx, A_mx, R_mx, B_mx, u0);
        end % GGG        
    end % TTT    
end % LLL

%----------------------------------------------------------------------
% Plot figures

line_col = [...
'-og'
'-ob'
'-om'
'-ok'];

Rmono = 2.8e-7; % cm, apo-(SH3)Cyt hydrodynamic radius
Dmono = kBT/(6*pi*etaH2O*Rmono);
STmono = [0, -Dmono]; % monomer attenuation in Stejskal-Tanner coordinates

xxx = (G_array/Gmax).^2;
for LLL = 1:length(rod_length_array)
    L = rod_length_array(LLL);
    
    figure;
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        
%         lllccc = line_col(LLL, :)
        if abs(BIG_DELTA - 5.4e-3) < 1e-5
            lllccc = '-or';
        elseif abs(BIG_DELTA - 1.0) < 1e-5
            lllccc = '-ob';
        else
            lllccc = '-og';
        end
            
        
%         plot(zzz, yyy*1e7, line_col(LLL, :));
        plot(zzz, yyy*1e7, lllccc);
        drawnow;
        hold on;        
    end % TTT
    plot([0 1], STmono*1e7, '-r');
    xlabel('(G/Gmax)^2');
    ylabel('1e7*ln(E)/(gamma*Gmax*sd)\^2/(BD - sd/3)');
    title(['Rod length = ' num2str(L*1e4) ' um']);
    axis([0, 1, -0.75, 0.05]);
    grid on;
    hold off;
    drawnow;
    pause(1);    
end % LLL

%----------------------------------------------------------------------

figure;
for LLL = 1:length(rod_length_array)
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL
plot([0 1], STmono*1e7, '-r');
xlabel('(G/Gmax)^2');
ylabel('1e7*ln(E)/(gamma*Gmax*sd)\^2/(BD - sd/3)');
title(['Red=mono, ' ...
       'Green='   num2str(rod_length_array(1)*1e4) 'um, ' ...
       'Blue='    num2str(rod_length_array(2)*1e4) 'um, ' ...
       'Magenta=' num2str(rod_length_array(3)*1e4) 'um, ' ...
       'Black='   num2str(rod_length_array(4)*1e4) 'um']);
axis([0, 1, -0.75, 0.05]);
% axis([0, 1, -8, 0.05]);
grid on;
drawnow;
pause(1);
hold off;

%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------
% The high quality plot
%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------

line_col = [...
'g'
'b'
'm'
'k'];

%----------------------------------------------------------------------

fig_for_publication = figure;
fig_for_publication.Units = 'centimeters';
fig_for_publication.Position = [3, 3, 16, 16*(3/4)];
ax1 = axes('Box','on'); % the main field of the figure
ax2 = axes('Position',[0.24, 0.18, 0.31, 0.31],'Box','on'); % the insert

%----------------------------------------------------------------------
% The main field of the figure

axes(ax1); 
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;
for LLL = 1:(length(rod_length_array) - 1) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

for LLL = length(rod_length_array) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1 % to avoid distorted PDF plot only one line for the last LLL
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1.5, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

ax1.LineWidth = 1.5;
axis([0, 1, -0.75, 0.05]);
grid on;
xlabel('$x_{\scriptscriptstyle{ST}}$', 'Interpreter', 'latex', 'FontSize', 20);
ylabel('$y_{\scriptscriptstyle{ST}} \ (10^{-7} \mathrm{cm}^2 \mathrm{s}^{-1} ) $', 'interpreter', 'latex','FontSize', 20);

text(1.01, -0.025, '$39\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'k');
text(1.01, -0.11, '$6.3\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'm');
text(1.01, -0.272, '$1.4\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'b');
text(1.01, -0.685, '$0.23\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'g');

hold off;
drawnow;
pause(1);

%----------------------------------------------------------------------
% The insert

axes(ax2);
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;
for LLL = 1:(length(rod_length_array) - 1) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

for LLL = length(rod_length_array) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1 % to avoid distorted PDF plot only one line for the last LLL
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1.5, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

ax2.LineWidth = 1.5;
axis([0, 1, -8, 0.05]);
xticks(0:0.2:1);
yticks(-8:2:0);
grid on;
text(1.02, -7.8, '$\mathrm{monomer}$', 'Interpreter', 'latex', 'Color', 'r');

hold off;
drawnow;
pause(1);

%----------------------------------------------------------------------

% exportgraphics(fig_for_publication,'Fig4.pdf','ContentType','vector');
% exportgraphics(fig_for_publication,'Fig4.eps','ContentType','vector');
% exportgraphics(fig_for_publication,'Fig4.emf','ContentType','vector');
% exportgraphics(fig_for_publication,'Fig4.tiff','Resolution',1200);

% --------------------------------------------------------------------

end % of function__Fig_4_RodEnd

