function [] = function__Fig_S2_FilledRod()
%function__Fig_S2_FilledRod
%   reads data from disk and plots Fig.S2


% ------------------------------------------------------------

ddd = './data/'; % full = translation + rotation
fff = 'saved_by_function_array_of_filled_rods_2020-06-10-03-23.mat';
ECHOloaded = load([ddd fff]);

rod_length_array = [0.23, 1.4, 6.3, 39]*1e-4; % in cm, 0.23, 1.4, 6.3, 39 um
rod_length_array_full = ECHOloaded.rod_length_array;
rla_idx = zeros(size(rod_length_array));
for iii = 1:length(rod_length_array)
    [~, kkk] = min(abs(rod_length_array_full - rod_length_array(iii)));
    rla_idx(iii) = kkk;
end

G_array = ECHOloaded.G_array;
Gmax = max(G_array);
small_delta = ECHOloaded.small_delta;
BIG_DELTA_array = ECHOloaded.BIG_DELTA_array;
T_full_array = BIG_DELTA_array + small_delta;
ECHO =  ECHOloaded.ECHO; % ECHO(LLL, TTT, GGG) 
ECHO = ECHO(rla_idx, :, :);

%----------------------------------------------------------------------

[gamma1H, kBT, etaH2O] = function_physical_consts();

%----------------------------------------------------------------------
% Plot figures

line_col = [...
'-og'
'-ob'
'-om'
'-ok'];

Rmono = 2.8e-7; % cm, apo-(SH3)Cyt hydrodynamic radius
Dmono = kBT/(6*pi*etaH2O*Rmono);
STmono = [0, -Dmono]; % monomer attenuation in Stejskal-Tanner coordinates

xxx = (G_array/Gmax).^2;
gGd2 = (gamma1H*Gmax*small_delta)^2;
for LLL = 1:length(rod_length_array)
    L = rod_length_array(LLL);
    
    figure;
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, line_col(LLL, :));
        drawnow;
        hold on;        
    end % TTT
    plot([0 1], STmono*1e7, '-r');
    xlabel('(G / G_{max})^2');
    ylabel('1e7*ln(E) / (\gamma*G_{max}*\delta)^2 / (\Delta - \delta/3)');
    title(['Rod length = ' num2str(L*1e4) ' \mum']);
    axis([0, 1, -0.75, 0.05]);
    grid on;
    hold off;
    drawnow;
    pause(1);    
end % LLL

%----------------------------------------------------------------------

figure;
gGd2 = (gamma1H*Gmax*small_delta)^2;
for LLL = 1:length(rod_length_array)
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;              
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL
plot([0 1], STmono*1e7, '-r');
xlabel('(G / G_{max})^2');
ylabel('1e7*ln(E) / (\gamma*G_{max}*\delta)^2 / (\Delta - \delta/3)');
title(['Red=mono, ' ...
       'Green='   num2str(rod_length_array(1)*1e4) ' \mum, ' ...
       'Blue='    num2str(rod_length_array(2)*1e4) ' \mum, ' ...
       'Magenta=' num2str(rod_length_array(3)*1e4) ' \mum, ' ...
       'Black='   num2str(rod_length_array(4)*1e4) ' \mum']);
axis([0, 1, -0.75, 0.05]);
% axis([0, 1, -8, 0.05]);
grid on;
drawnow;
pause(1);
hold off;

%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------
% The high quality plot
%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------

line_col = [...
'g'
'b'
'm'
'k'];

%----------------------------------------------------------------------

fig_for_publication = figure;
fig_for_publication.Units = 'centimeters';
fig_for_publication.Position = [3, 3, 16, 16*(3/4)];
ax1 = axes('Box','on'); % the main field of the figure
ax2 = axes('Position',[0.24, 0.18, 0.31, 0.31],'Box','on'); % the insert

%----------------------------------------------------------------------
% The main field of the figure

axes(ax1); 
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;

gGd2 = (gamma1H*Gmax*small_delta)^2;
for LLL = 1:(length(rod_length_array) - 1) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;        
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

gGd2 = (gamma1H*Gmax*small_delta)^2;
for LLL = length(rod_length_array) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1 % to avoid distorted PDF plot only one line for the last LLL
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
                
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1.5, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

ax1.LineWidth = 1.5;
axis([0, 1, -0.75, 0.05]);
grid on;
xlabel('$x_{\scriptscriptstyle{ST}}$', 'Interpreter', 'latex', 'FontSize', 20);
ylabel('$y_{\scriptscriptstyle{ST}} \ (10^{-7} \mathrm{cm}^2 \mathrm{s}^{-1} ) $', 'interpreter', 'latex','FontSize', 20);

text(1.01, -0.015, '$39\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'k');
text(1.01, -0.07, '$6.3\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'm');
text(1.01, -0.205, '$1.4\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'b');
text(1.01, -0.677, '$0.23\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'g');

hold off;
drawnow;
pause(1);

%----------------------------------------------------------------------
% The insert

axes(ax2);
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;
for LLL = 1:(length(rod_length_array) - 1) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1:length(T_full_array)
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

for LLL = length(rod_length_array) % to avoid distorted PDF plot the last LLL separately
    for TTT = 1 % to avoid distorted PDF plot only one line for the last LLL
        T = T_full_array(TTT);
        BIG_DELTA = T - small_delta;
        beta = BIG_DELTA - small_delta/3;
        gGd2 = (gamma1H*Gmax*small_delta)^2;
        
        yyy = squeeze(ECHO(LLL, TTT, :));
        idx = find(yyy > 1e-6, 1, 'last');
        if idx < length(yyy)
            disp(idx);
        end
        yyy = log(yyy(1:idx)); % discard too weak echoes
        zzz = xxx(1:idx);
        yyy = yyy/gGd2/beta;
        plot(zzz, yyy*1e7, 'Marker', '.', 'MarkerEdgeColor',  line_col(LLL, :), 'MarkerFaceColor', line_col(LLL, :), 'MarkerSize', 12);
        hold on;
        plot([0, 1], [0, yyy(end)*1e7], 'LineStyle', '-', 'LineWidth', 1.5, 'Color', line_col(LLL, :));
        hold on;
        drawnow;
    end % TTT    
end % LLL

ax2.LineWidth = 1.5;
axis([0, 1, -8, 0.05]);
xticks(0:0.2:1);
yticks(-8:2:0);
grid on;
text(1.02, -7.8, '$\mathrm{monomer}$', 'Interpreter', 'latex', 'Color', 'r');

hold off;
drawnow;
pause(1);

%----------------------------------------------------------------------

% exportgraphics(fig_for_publication,'FigS2.pdf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS2.eps','ContentType','vector');
% % exportgraphics(fig_for_publication,'FigS2.emf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS2.tiff','Resolution',1200);

% --------------------------------------------------------------------

end % of function__Fig_S2_FilledRod

