function [] = function__Fig_S3_LrodDistribution()
%function__Fig_S3_LrodDistribution
%   reads data from disk and plots Fig.S3

% ------------------------------------------------------------

ECHOloaded = load('./data/saved_by_function_array_of_filled_rods_2020-06-10-03-23.mat');

rod_length_array = ECHOloaded.rod_length_array;
G_array = ECHOloaded.G_array;
Gmax = max(G_array);
small_delta = ECHOloaded.small_delta;
BIG_DELTA_array = ECHOloaded.BIG_DELTA_array;
T_full_array = ECHOloaded.T_full_array;
ECHO = ECHOloaded.ECHO; % ECHO(LLL, TTT, GGG)

% ------------------------------------------------------------

[gamma1H, kBT, etaH2O] = function_physical_consts();

% ------------------------------------------------------------

Rmono = 2.8e-7; % cm, apo-(SH3)Cyt hydrodynamic radius
Dmono = kBT/(6*pi*etaH2O*Rmono);
STmono = [0, -Dmono]; % monomer attenuation in Stejskal-Tanner coordinates

% ------------------------------------------------------------
% log-normal distribution

a0 = 9*1e-4; % in cm, 9 um
a1 = 0.6;
mu_ln = log(a0);
sigma_ln = a1;

% ------------------------------------------------------------

figure;
plot([0 1], STmono*1e7, '-r');
hold on;
drawnow;
pause(1);

% ------------------------------------------------------------
% log-normal, 1 percent of max threshold, left part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(maxIDX:end) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pleft = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    plot(xxx, echo_mean_ST_T_G(TTT, :)*1e7, 'og');
    hold on;
    plot([0 1], [0, echo_mean_ST_T_G(TTT, end)*1e7], '-g'); 
    drawnow;
    hold on;        
end % TTT
grid on;
axis([0 1 -0.75 0.05]);
drawnow;
pause(1);

% ------------------------------------------------------------
% log-normal, 1 percent of max threshold

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, ~] = max(relative_probability_L);
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pfull = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    plot(xxx, echo_mean_ST_T_G(TTT, :)*1e7, 'ob');
    hold on;
    plot([0 1], [0, echo_mean_ST_T_G(TTT, end)*1e7], '-b'); 
    drawnow;
    hold on;        
end % TTT
grid on;
axis([0 1 -0.75 0.05]);
drawnow;
pause(1);

% ------------------------------------------------------------
% log-normal, 1 percent of max threshold, right part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(1:(maxIDX - 1)) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pright = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    plot(xxx, echo_mean_ST_T_G(TTT, :)*1e7, 'ok');
    hold on;
    plot([0 1], [0, echo_mean_ST_T_G(TTT, end)*1e7], '-k'); 
    drawnow;
    hold on;        
end % TTT
grid on;
axis([0 1 -0.75 0.05]);
title('red=mono; log-norm-distr filled rods: green=left, blue=full, black=right');
xlabel('(G / G_{max})^2');
ylabel('ln(E) / (\gamma G_{max} \delta)^2 / (\Delta - \delta/3)  (10^{-7} cm^2 s^{-1})');
drawnow;
pause(1);
hold off;


% ------------------------------------------------------------

figure;
xxx = rod_length_array;
semilogx(xxx*1e4, pleft*1e3, '-g', xxx*1e4, pfull*1e3, '-b', xxx*1e4, pright*1e3, '-k');
title('log-normal distr: green=left, blue=full, black=right');
xlabel('Rod Lenght (\mum)');
ylabel('1000*Probability')
grid on;
drawnow;
pause(1);

%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------
% The high quality plot
%----------------------------------------------------------------------
%----------------------------------------------------------------------
%----------------------------------------------------------------------

% line_col = [...
% 'g'
% 'b'
% 'm'
% 'k'];

%----------------------------------------------------------------------

fig_for_publication = figure;
fig_for_publication.Units = 'centimeters';
fig_for_publication.Position = [3, 3, 16, 16*(3/4)];
ax1 = axes('Box','on'); % the main field of the figure
ax2 = axes('Position',[0.22, 0.50, 0.31, 0.31],'Box','on'); % the first insert
ax3 = axes('Position',[0.58, 0.22, 0.31, 0.31],'Box','on'); % the second insert

%----------------------------------------------------------------------
% The main field of the figure
%----------------------------------------------------------------------

axes(ax1); 
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;

% ------------------------------------------------------------
% The main field: log-normal, 1 percent of max threshold, left part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(maxIDX:end) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'g', ...
                'MarkerFaceColor', 'g', ...
                'MarkerSize', 12); 
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'g'); 
            
    drawnow;
    hold on;        
end % TTT
grid on;
drawnow;
pause(1);

% ------------------------------------------------------------
% The main field: log-normal, 1 percent of max threshold

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, ~] = max(relative_probability_L);
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'b', ...
                'MarkerFaceColor', 'b', ...
                'MarkerSize', 12);
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'b'); 
    drawnow;
    hold on;        
end % TTT
grid on;
drawnow;
pause(1);

% ------------------------------------------------------------
% The main field: log-normal, 1 percent of max threshold, right part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(1:(maxIDX - 1)) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'm', ...
                'MarkerFaceColor', 'm', ...
                'MarkerSize', 12); 
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'm'); 
    drawnow;
    hold on;        
end % TTT
grid on;
ax1.LineWidth = 1.5;
axis([0 1 -0.75 0.05]);

xlabel('$x_{\scriptscriptstyle{ST}}$', 'Interpreter', 'latex', 'FontSize', 20);
ylabel('$y_{\scriptscriptstyle{ST}} \ (10^{-7} \mathrm{cm}^2 \mathrm{s}^{-1} ) $', 'interpreter', 'latex','FontSize', 20);

% text(0.93, -0.02, 'A', 'FontWeight', 'bold', 'FontSize', 18);
% text(0.93, 0, 'A', 'FontWeight', 'bold', 'FontSize', 18);
% text(0.93, 0.01, 'A', 'FontWeight', 'bold', 'FontSize', 18);

drawnow;
pause(1);
hold off;

%----------------------------------------------------------------------
% The first insert
%----------------------------------------------------------------------

axes(ax2);
plot([0 1], STmono*1e7, '-r', 'LineWidth', 1.5);
hold on;

% ------------------------------------------------------------
% The first insert: log-normal, 1 percent of max threshold, left part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(maxIDX:end) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pleft = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)    
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'g', ...
                'MarkerFaceColor', 'g', ...
                'MarkerSize', 12); 
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'g');          
    drawnow;
    hold on;        
end % TTT
grid on;
drawnow;
pause(1);

% ------------------------------------------------------------
% The first insert: log-normal, 1 percent of max threshold

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, ~] = max(relative_probability_L);
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pfull = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)    
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'b', ...
                'MarkerFaceColor', 'b', ...
                'MarkerSize', 12);
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'b'); 
    drawnow;
    hold on;        
end % TTT
grid on;
drawnow;
pause(1);

% ------------------------------------------------------------
% The first insert: log-normal, 1 percent of max threshold, right part

relative_probability_L = lognpdf(rod_length_array, mu_ln, sigma_ln);
[MMM, maxIDX] = max(relative_probability_L);
relative_probability_L(1:(maxIDX - 1)) = 0;
IDX = relative_probability_L < MMM/100;
relative_probability_L(IDX) = 0;

pright = relative_probability_L/sum(relative_probability_L);

echo_mean_ST_T_G = zeros(length(T_full_array), length(G_array));
denominator = sum(relative_probability_L.*rod_length_array);
gGd2 = (gamma1H*Gmax*small_delta)^2;
for TTT = 1:length(T_full_array)
    beta = BIG_DELTA_array(TTT) - small_delta/3;
    for GGG = 1:length(G_array)
        numerator = sum(relative_probability_L.*rod_length_array.*ECHO(:, TTT, GGG)');
        eee = numerator/denominator;
        echo_mean_ST_T_G(TTT, GGG) = log(eee)/gGd2/beta;
    end
end

xxx = (G_array/Gmax).^2;
for TTT = 1:length(T_full_array)   
    yyy = echo_mean_ST_T_G(TTT, :)*1e7;
    plot(xxx, yyy, ...
                'Marker', '.', ...
                'MarkerEdgeColor',  'm', ...
                'MarkerFaceColor', 'm', ...
                'MarkerSize', 12); 
    drawnow;
    hold on;
    plot([0 1], [0, yyy(end)], ...
                'LineStyle', '-', ...
                'LineWidth', 1, ...
                'Color', 'm'); 
    drawnow;
    hold on;        
end % TTT
ax2.LineWidth = 1.5;
grid on;
axis([0 1 -0.095 0.005]);
xticks(0:0.2:1);
yticks(-0.08:0.02:0);

% text(0.9, -0.01, 'B', 'FontWeight', 'bold', 'FontSize', 18);
% text(0.85, -0.01, 'B', 'FontWeight', 'bold', 'FontSize', 18);
text(0.85, -0.01, 'A', 'FontWeight', 'bold', 'FontSize', 18);

drawnow;
pause(1);
hold off;

%----------------------------------------------------------------------
% The second insert
%----------------------------------------------------------------------

axes(ax3);
xxx = rod_length_array*1e4;

yyy = pleft*1e3;
semilogx(xxx, yyy, '-g', 'LineWidth', 2);
drawnow;
hold on;
yyy = pfull*1e3;
semilogx(xxx, yyy, '-b', 'LineWidth', 2);
drawnow;
hold on;
yyy = pright*1e3;
semilogx(xxx, yyy, '-m', 'LineWidth', 2);
drawnow;
            
axis([0.5 50 0 3.5]);
yticks(0:1:3);
xticks([1, 10]);
            
ax3.LineWidth = 1.5;           

xlabel('$L_{rod} = L_{k}\ \mathrm{(} \mathrm{\mu} \mathrm{m)}$ ', 'Interpreter', 'latex', 'FontSize', 10);
% ylabel('$1000p_{k}^{left}, 1000p_{k}, 1000p_{k}^{right}$', 'interpreter', 'latex','FontSize', 10);
% ylabel('$10^3(p_{k}^{left}, p_{k}, p_{k}^{right})$', 'interpreter', 'latex','FontSize', 10);
ylabel('$10^3p_{k}$', 'interpreter', 'latex','FontSize', 10);

grid on;
drawnow;
pause(1);
hold off;

% text(1.01, -0.015, '$39\ \mathrm{\mu}\mathrm{m}$', 'Interpreter', 'latex', 'Color', 'k');
% text(30, 3.2, 'C', 'FontWeight', 'bold', 'FontSize', 18);
% text(25, 2.7, 'C', 'FontWeight', 'bold', 'FontSize', 18);
% text(25, 2.9, 'C', 'FontWeight', 'bold', 'FontSize', 18);
% text(25, 3, 'C', 'FontWeight', 'bold', 'FontSize', 18);
text(25, 3, 'B', 'FontWeight', 'bold', 'FontSize', 18);


% text(-1, YMAX12*1.45/1.25, 'A', 'FontWeight', 'bold', 'FontSize', 18);

%----------------------------------------------------------------------

% exportgraphics(fig_for_publication,'FigS3.pdf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS3.eps','ContentType','vector');
% % exportgraphics(fig_for_publication,'FigS3.emf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS3.tiff','Resolution',600);

%----------------------------------------------------------------------

end % of function__Fig_S3_LrodDistribution

