function [] = function__Fig_S4_SmallMinimum()
%function__Fig_S4_SmallMinimum
%   reads data from disk, performs calculations according to Eqs.(S50), (S51), (S56)
%   and plots Fig.S4.

% ------------------------------------------------------------
% full = translation + rotation

ddd = './data/'; 
fff = 'saved_by_function_array_of_end_point_labeled_rods_2020-06-06-21-48.mat';
ECHOloaded = load([ddd fff]);

rod_length_array = ECHOloaded.rod_length_array;

shorter_1_micron_idx = rod_length_array <= 1e-4; 
rod_length_array = rod_length_array(shorter_1_micron_idx);

G_array = ECHOloaded.G_array;
Gmax = max(G_array);
small_delta = ECHOloaded.small_delta;
BIG_DELTA_array = ECHOloaded.BIG_DELTA_array;
rod_width = ECHOloaded.rod_width;
echo_L_T_G_array =  ECHOloaded.ECHO; % ECHO(LLL, TTT, GGG) 
echo_L_T_G_array = echo_L_T_G_array(shorter_1_micron_idx, :, :);

% ------------------------------------------------------------
% translation only

ddd = './data/';
fff = 'saved_by_function_array_of_end_point_labeled_rods_transl_only_2020-06-06-22-20.mat';
ECHOloaded = load([ddd fff]);
rod_length_translation_only_array = ECHOloaded.rod_length_array;
rod_length_translation_only_array = rod_length_translation_only_array(shorter_1_micron_idx);
G_translation_only_array = ECHOloaded.G_array;
Gmax_translation_only = max(G_translation_only_array);
small_delta_translation_only = ECHOloaded.small_delta;
BIG_DELTA_translation_only_array = ECHOloaded.BIG_DELTA_array;
rod_width_translation_only = ECHOloaded.rod_width;

if length(rod_length_translation_only_array) ~= length(rod_length_array) 
    disp(' ');
    disp('function\_\_Fig\_S4_SmallMinimum: ERROR #1 !!!');
    disp(' ');
    return;
end

if length(G_translation_only_array) ~= length(G_array) 
    disp(' ');
    disp('function\_\_Fig\_S4_SmallMinimum: ERROR #2: !!!');
    disp(' ');
    return;
end

if length(BIG_DELTA_translation_only_array) ~= length(BIG_DELTA_array) 
    disp(' ');
    disp('function\_\_Fig\_S4_SmallMinimum: ERROR #3: !!!');
    disp(' ');
    return;
end

C1 = sum(rod_length_translation_only_array ~=  rod_length_array);
C2 = sum(G_translation_only_array ~=  G_array);
C3 = Gmax_translation_only ~=  Gmax;
C4 = small_delta_translation_only ~=  small_delta;
C5 = sum(BIG_DELTA_translation_only_array ~=  BIG_DELTA_array);
C6 = rod_width_translation_only ~=  rod_width;

if C1 + C2 + C3 + C4 + C5 + C6 > 0
    disp(' ');
    disp('function\_\_Fig\_S4_SmallMinimum: ERROR #4 !!!');
    disp(' ');
    return;
end

echo_L_T_G_translation_only_array = ECHOloaded.ECHO; % ECHO(LLL, TTT, GGG)
echo_L_T_G_translation_only_array = echo_L_T_G_translation_only_array(shorter_1_micron_idx, :, :);

% ------------------------------------------------------------

[BIG_DELTA_array, IDX] = sort(BIG_DELTA_array);
echo_L_T_G_array = echo_L_T_G_array(:, IDX, :);
echo_L_T_G_translation_only_array = echo_L_T_G_translation_only_array(:, IDX, :);

% ------------------------------------------------------------

[D0_array, ~, ~] = function_rod_diffusion_coefficients(rod_length_array, rod_width);

% ------------------------------------------------------------

[gamma1H, ~, ~] = function_physical_consts();
gGd2 = (gamma1H*Gmax*small_delta)^2;

% ------------------------------------------------------------

TTT = length(BIG_DELTA_array);

bbb = BIG_DELTA_array(TTT) - small_delta/3;
yyy = echo_L_T_G_array(:, TTT, end);
yyy = -log(yyy)/bbb/gGd2;
D_app_full = yyy;

yyy = echo_L_T_G_translation_only_array(:, TTT, end);    
yyy = -log(yyy)/bbb/gGd2;
D_app_transl = yyy;

D_app_rot_contr = D_app_full - D_app_transl;
blue_line = D_app_rot_contr;

%-----------------------------------------------------

% Eq.(S50):
rot_contribution = (1/3)*(1/BIG_DELTA_array(TTT))*(rod_length_array/2).^2;

% Eq.(S51):
eps_contribution = D0_array - D_app_transl'; 

% Eq.(S56):
summ_contribution = rot_contribution + eps_contribution;

%-----------------------------------------------------

figure;
xxx = rod_length_array;
plot(xxx*1e4, blue_line*1e7, '-b',  ...
     xxx*1e4, eps_contribution*1e7, '--m', ...
     xxx*1e4, rot_contribution*1e7, '--c',  ...
     xxx*1e4, summ_contribution*1e7, '--k', 'LineWidth', 2);
grid on;
xlabel('L_{rod} (\mum)');
ylabel('D^{app}_{rot\_contr} (10^{-7}cm^2s^{-1})');
axis([0 1 0 0.015]);
drawnow;
pause(1); 

% ------------------------------------------------------------
% ------------------------------------------------------------
% ------------------------------------------------------------
% Publication quality plot
% ------------------------------------------------------------
% ------------------------------------------------------------
% ------------------------------------------------------------

fig_for_publication = figure;
fig_for_publication.Units = 'centimeters';
fig_for_publication.Position = [3, 3, 16, 16*(3/4)];
ax1 = axes('Box','on'); % the main field of the figure

%----------------------------------------------------------------------

xxx = rod_length_array;
plot(xxx*1e4, blue_line*1e7, '-b',  ...
     xxx*1e4, eps_contribution*1e7, '--m', ...
     xxx*1e4, rot_contribution*1e7, '--c',  ...
     xxx*1e4, summ_contribution*1e7, '--k', 'LineWidth', 2);
grid on;

% title('$D^{app}_{rot\_contr}=D^{app}-D^{app}_{transl}$', 'interpreter', 'latex','FontSize', 20);
title('$D^{app}_{rot.contrib.}=D^{app}-D^{app}_{transl}$', 'interpreter', 'latex','FontSize', 20);
xlabel('$L_{rod}\ \mathrm{(} \mathrm{\mu} \mathrm{m)}$ ', 'Interpreter', 'latex', 'FontSize', 20);
% ylabel('$D^{app}_{rot\_contr} \ (10^{-7} \mathrm{cm}^2 \mathrm{s}^{-1} ) $', 'interpreter', 'latex','FontSize', 20);
ylabel('$D^{app}_{rot.contrib.} \ (10^{-7} \mathrm{cm}^2 \mathrm{s}^{-1} ) $', 'interpreter', 'latex','FontSize', 20);
axis([0 1 0 0.015]);
ax1.LineWidth = 1.5;

drawnow;
pause(1);

%----------------------------------------------------------------------

% exportgraphics(fig_for_publication,'FigS4.pdf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS4.eps','ContentType','vector');
% % exportgraphics(fig_for_publication,'FigS4.emf','ContentType','vector');
% exportgraphics(fig_for_publication,'FigS4.tiff','Resolution',1200);

% ------------------------------------------------------------

end % of function__Fig_S4_SmallMinimum

