function [D0_array, eps_aniso_array, Drot_array] = function_rod_diffusion_coefficients(rod_length_array, rod_width)
%function_rod_diffusion_coefficients 
%  Rod diffusion coefficients, Eqs.(137)-(139)

%----------------------------------------------------------------------

[~, kBT, etaH2O] = function_physical_consts();

%----------------------------------------------------------------------
% Diffusion coefficients (main terms) according to 
%
% S. Broersma, 
% Viscous force and torque constants for a cylinder, 
% The Journal of Chemical Physics. 74 (1981) 6989–6990. 
% doi:10.1063/1.441071.
%
% in notation of
%
% M.M. Tirado, C.L. Martínez, J.G. de la Torre, 
% Comparison of theories for the translational and rotational diffusion 
% coefficients of rod‐like macromolecules. Application to short DNA fragments, 
% The Journal of Chemical Physics. 81 (1984) 2047–2052. 
% doi:10.1063/1.447827.
%

parameter_p = rod_length_array/rod_width;

v_slow_broersma_short = 0.866;
v_fast_broersma_short = -0.114;
d_rot_broersma_short = -0.446;

D1_array = kBT*(log(parameter_p) + v_slow_broersma_short)./(4*pi*etaH2O*rod_length_array);
D2_array = kBT*(log(parameter_p) + v_fast_broersma_short)./(2*pi*etaH2O*rod_length_array);
Drot_array = 3*kBT*(log(parameter_p) + d_rot_broersma_short)./(pi*etaH2O*rod_length_array.^3);

D0_array = (2*D1_array + D2_array)/3;
eps_aniso_array = (D2_array - D1_array)./D0_array;

%----------------------------------------------------------------------

end % of function_rod_diffusion_coefficients

